@@ -58,7 +58,6 @@ AwsCreds = namedtuple('AwsCreds', [
     'access_key_id', 'secret_access_key', 'pre_auth_headers',
 ])
 
-s3_client = None
 
 class ExpiringDict:
 
@@ -113,9 +112,7 @@ class CortxJupyterSecretAccessKeyAuthentication(CortxJupyterAuthentication):
             secret_access_key=self.aws_secret_access_key,
             pre_auth_headers=self.pre_auth_headers,
         )
-    s3_client = boto3.client('s3', aws_access_key_id=self.aws_access_key_id,
-                         aws_secret_access_key=self.aws_secret_access_key, region_name='us-east-1', endpoint_url="https://s3.amazonaws.com")
-
+    
 
 
 class CortxJupyter(ContentsManager):
@@ -311,7 +308,7 @@ def _file_exists(context, path):
     @gen.coroutine
     def key_exists():
         key = _key(context, path)
-        response = yield _head_object(context.s3_bucket, key)
+        response = yield _head_object(context, context.s3_bucket, key)
 
         return response
 
@@ -351,7 +348,7 @@ def _get_file_text(context, path, content):
 def _get_any(context, path, content, type, mimetype, format, decode):
     method = 'GET' if content else 'HEAD'
     key = _key(context, path)
-    response = yield _get_object(context.s3_bucket, key)
+    response = yield _get_object(context, context.s3_bucket, key)
 
     file_bytes = response.Body
     last_modified_str = response.LastModified
@@ -471,7 +468,7 @@ def _save_chunk(context, chunk, content_bytes, path, type, mimetype):
 @gen.coroutine
 def _save_bytes(context, content_bytes, path, type, mimetype):
     object_name = _key(context, path)
-    _put_object(context.s3_bucket, content_bytes, object_name)
+    _put_object(context, context.s3_bucket, content_bytes, object_name)
 
     last_modified_str = response.headers['Date']
     last_modified = datetime.datetime.strptime(
@@ -600,7 +597,7 @@ def _rename(context, old_path, new_path):
 
 @gen.coroutine
 def _copy_key(context, old_key, new_key):
-    yield _copy_object(context.s3_bucket, f'/{context.s3_bucket}/{old_key}', new_key)
+    yield _copy_object(context, context.s3_bucket, f'/{context.s3_bucket}/{old_key}', new_key)
 
 
 @gen.coroutine
@@ -626,7 +623,7 @@ def _delete(context, path):
 
 @gen.coroutine
 def _delete_key(context, key):
-    yield _delete_object(context.s3_bucket, key)
+    yield _delete_object(context, context.s3_bucket, key)
 
 
 @gen.coroutine
@@ -725,7 +722,7 @@ def _list_keys(context, key_prefix, delimiter):
     @gen.coroutine
     def _list_first_page():
         print(type(context.s3_bucket))
-        response = yield _list_objects(context.s3_bucket, key_prefix, delimiter, max_keys)
+        response = yield _list_objects(context, context.s3_bucket, key_prefix, delimiter, max_keys)
 
 
         return _parse_list_response(response)
@@ -733,7 +730,7 @@ def _list_keys(context, key_prefix, delimiter):
     @gen.coroutine
     def _list_later_page(token):
 
-        response = yield _list_objects(context.s3_bucket, key_prefix, delimiter, max_keys, token)
+        response = yield _list_objects(context, context.s3_bucket, key_prefix, delimiter, max_keys, token)
 
         return _parse_list_response(response)
 
@@ -807,9 +804,15 @@ SAVERS = {
 
 # 'endpoint_url': AwsCreds.endpoint_url,
 
+def _initialize_context(context):
+    credentials = context.s3_auth()
+    return boto3.client('s3', aws_access_key_id=credentials.aws_access_key_id,
+                         aws_secret_access_key=credentials.aws_secret_access_key, region_name='us-east-1', endpoint_url="https://s3.amazonaws.com")
 
 
-def _head_object(bucket, key):
+
+def _head_object(context, bucket, key):
+    s3_client = _initialize_context(context)
     response = s3_client.head_object(Bucket=bucket, Key=key)
     if 'ContentLength' in response and response['ContentLength'] >= 0:
         return True
@@ -817,32 +820,37 @@ def _head_object(bucket, key):
         return False
 
 
-def _put_object(bucket, body, object_name):
-
+def _put_object(context, bucket, body, object_name):
+    s3_client = _initialize_context(context)
     # Upload the file
     return s3_client.put_object(Body=body, Bucket=bucket, Key=object_name)
 
 
-def _get_object(bucket, object_name):
-
+def _get_object(context, bucket, object_name):
+    s3_client = _initialize_context(context)
     # Download the file
     return s3_client.get_object(Bucket=bucket, Key=object_name)
 
 
-def _list_buckets():
+def _list_buckets(context):
     # Retrieve the list of existing buckets
+    s3_client = _initialize_context(context)
+
     return s3_client.list_buckets()
 
 
-def _copy_object(bucket, source_file, destination_file):
+def _copy_object(context, bucket, source_file, destination_file):
+    s3_client = _initialize_context(context)
     return s3_client.copy_object(Bucket=bucket, CopySource=source_file, Key=destination_file)
 
 
-def _delete_object(bucket, file_name):
+def _delete_object(context, bucket, file_name):
+    s3_client = _initialize_context(context)
     return s3_client.delete_object(Bucket=bucket, Key=file_name)
 
 
-def _list_objects(bucket, prefix, delimiter, max_keys, token=''):
+def _list_objects(context, bucket, prefix, delimiter, max_keys, token=''):
+    s3_client = _initialize_context(context)
     return s3_client.list_objects_v2(
         Bucket=bucket,
         Delimiter=delimiter,
